@@ -100,6 +100,36 @@ class DatasetApi(IteratorBaseApi):
             header_params,
             query_params)
 
+    def find_by_dataset_template_id(self, dataset_template_id: str, projection: str = None):
+        """
+        returns a dataset of a project by name
+
+        Parameters:
+           dataset_template_id (str): dataset_template_id
+           projection (str): projection type
+
+        Returns:
+            (dict): datasets
+        """
+        header_vars = ['AOA-Project-ID', 'Accept']
+        header_vals = [
+            self.aoa_client.project_id,
+            self.aoa_client.select_header_accept([
+                'application/json',
+                'application/hal+json',
+                'text/uri-list',
+                'application/x-spring-data-compact+json'])]
+        header_params = self.generate_params(header_vars, header_vals)
+
+        query_vars = ['datasetTemplateId', 'projection']
+        query_vals = [dataset_template_id, projection]
+        query_params = self.generate_params(query_vars, query_vals)
+
+        return self.aoa_client.get_request(
+            self.path + "search/findByDatasetTemplateId",
+            header_params,
+            query_params)
+
     def save(self, dataset: Dict[str, str]):
         """
         register a dataset
