@@ -153,7 +153,7 @@ class ModelApi(IteratorBaseApi):
                 'application/x-spring-data-compact+json'])]
         header_params = self.generate_params(header_vars, header_vals)
 
-        self.required_params(['name', 'description', 'externalModelAttributes'], model)
+        self.required_params(['name', 'description', 'byomAttributes', 'language'], model)
 
         query_params = {}
 
