@@ -2,9 +2,7 @@ from __future__ import absolute_import
 from typing import Dict, List
 
 from aoa.api.iterator_base_api import IteratorBaseApi
-
-import requests
-import os
+from aoa.api.trained_model_artefacts_api import TrainedModelArtefactsApi
 
 
 class TrainedModelApi(IteratorBaseApi):
@@ -315,23 +313,11 @@ class TrainedModelApi(IteratorBaseApi):
             query_params,
             trained_model)
 
-        self.upload_artefacts(artefacts, response['id'])
+        trained_model_artefacts_api = TrainedModelArtefactsApi(self.aoa_client)
+        trained_model_artefacts_api.upload_artefacts(response['id'], artefacts)
 
         return response
 
-    def upload_artefacts(self, artefacts, trained_model_id):
-        for artefact in artefacts:
-            query_params = {
-                'objectKey': "{}".format(os.path.basename(artefact))
-            }
-            header_params = {
-                'AOA-Project-ID': "{}".format(self.aoa_client.project_id)
-            }
-            signed_url = self.aoa_client.get_request("/api/trainedModels/{}/artefacts/signedUploadUrl".format(trained_model_id), header_params, query_params)
-
-            upload_resp = requests.put(signed_url['endpoint'], data=open(artefact, 'rb'))
-            upload_resp.raise_for_status()
-
     def approve(self, trained_model_id: str, note: str):
         transition_request = dict()
         transition_request['status'] = 'APPROVED'
