@@ -1,15 +1,15 @@
 from aoa.model_utility.base_model import BaseModel
-from aoa.model_utility.model_utility import ModelUtility
 import json
 import os
-import sys
+import importlib
 import logging
 import shutil
+import sys
 
 
 class EvaluateModel(BaseModel):
 
-    def __init__(self, model_utility: ModelUtility):
+    def __init__(self, model_utility):
         super().__init__(model_utility)
         self.logger = logging.getLogger(__name__)
 
@@ -28,11 +28,15 @@ class EvaluateModel(BaseModel):
 
         model_artefacts_path = ".artefacts/{}".format(model_id)
         model_evaluation_path = "{}/evaluation".format(model_artefacts_path)
+
+        if not os.path.exists("{}/output".format(model_artefacts_path)):
+            raise ValueError("You must run training before trying to run evaluation.")
+
         if os.path.exists(model_evaluation_path):
             self.logger.debug("Cleaning local model evaluation path: {}".format(model_evaluation_path))
             shutil.rmtree(model_evaluation_path)
-        if os.path.exists("{}/output".format(model_artefacts_path)):
-            os.makedirs("{}/output".format(model_evaluation_path))
+
+        os.makedirs("{}/output".format(model_evaluation_path))
 
         try:
             self.__cleanup()
@@ -44,16 +48,10 @@ class EvaluateModel(BaseModel):
             os.symlink("../{}/evaluation/output/".format(model_artefacts_path), "./artifacts/output", target_is_directory=True)
 
             if not os.path.exists("./models"):
-                os.symlink(model_artefacts_path, "./models", target_is_directory=True)
+                os.symlink("{}/output".format(model_artefacts_path), "./models", target_is_directory=True)
 
             model_dir = model_path + model_id
 
-            cli_model_kargs = {
-                "model_id": model_id,
-                "model_version": "cli",
-                "model_table": "AOA_MODELS_cli"
-            }
-
             with open(model_dir + "/model.json", 'r') as f:
                 model_definition = json.load(f)
 
@@ -62,14 +60,21 @@ class EvaluateModel(BaseModel):
 
             self.logger.info("Loading and executing model code")
 
-            engine = self._BaseModel__get_engine(model_definition)
+            cli_model_kargs = self._BaseModel__get_model_varargs(model_id)
+
+            engine = self._BaseModel__get_engine(model_definition, "evaluation")
             if engine == "python" or engine == "pyspark":
                 if engine == "pyspark":
-                    self._BaseModel__configure_pyspark(model_definition, model_artefacts_path, model_dir)
+                    self._BaseModel__configure_pyspark(model_definition, model_artefacts_path, model_dir, "evaluation")
 
                 sys.path.append(model_dir)
-                import model_modules
-                model_modules.scoring.evaluate(data_conf, model_conf, **cli_model_kargs)
+                if os.path.isfile("{}/model_modules/evaluation.py".format(model_dir)):
+                    evaluation = importlib.import_module(".evaluation", package="model_modules")
+                else:
+                    logging.debug("No evaluation.py found. Using scoring.py -> evaluate")
+                    evaluation = importlib.import_module(".scoring", package="model_modules")
+
+                evaluation.evaluate(data_conf, model_conf, **cli_model_kargs)
 
             elif engine == "sql":
                 self.__evaluate_sql(model_dir, data_conf, model_conf, **cli_model_kargs)
@@ -94,6 +99,7 @@ class EvaluateModel(BaseModel):
             self.__cleanup()
         except:
             self.__cleanup()
+            self.logger.exception("Exception running model code")
             raise
 
     def __cleanup(self):
@@ -116,7 +122,7 @@ class EvaluateModel(BaseModel):
                        password=os.environ["TD_PASSWORD"],
                        logmech=os.getenv("TD_LOGMECH", "TDNEGO"))
 
-        sql_file = model_dir + "/model_modules/scoring.sql"
+        sql_file = model_dir + "/model_modules/evaluation.sql"
         jinja_ctx = {
             "data_conf": data_conf,
             "model_conf": model_conf,
