@@ -1,7 +1,7 @@
 import pandas as pd
 from sklearn.neighbors import KNeighborsClassifier
 from sklearn.externals import joblib
-import os
+
 
 def train(data_conf, model_conf, **kwargs):
     """Python train method called by AOA framework
@@ -29,8 +29,5 @@ def train(data_conf, model_conf, **kwargs):
     knn.fit(X,y)
     print("Finished training")
 
-    # export model artefacts to models/ folder
-    if not os.path.exists('models'):
-        os.makedirs('models')
-    joblib.dump(knn, 'models/iris_knn.joblib')
+    joblib.dump(knn, 'artifacts/output/iris_knn.joblib')
     print("Saved trained model")
\ No newline at end of file
